@@ -18,10 +18,9 @@ import os.path
 
 import fixtures
 from oslo.config import cfg
+from oslotest import moxstubout
 import testtools
 
-from pycadf.openstack.common.fixture import moxstubout
-
 
 class TestCase(testtools.TestCase):
 
